# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState, LinkTypes


class GetPerson(BaseModel):
    person: Optional["GetPersonPerson"]


class GetPersonPerson(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    owner: "GetPersonPersonOwner"
    state: EntityState
    alternate_names: Optional[List[Optional[str]]] = Field(alias="alternateNames")
    uri: Optional[Any]
    description: Optional[str]
    identifier: Optional[str]
    thing: Optional[str]
    feeds: Optional[List[Optional["GetPersonPersonFeeds"]]]
    links: Optional[List[Optional["GetPersonPersonLinks"]]]
    workflow: Optional["GetPersonPersonWorkflow"]
    location: Optional["GetPersonPersonLocation"]
    h_3: Optional["GetPersonPersonH3"] = Field(alias="h3")
    address: Optional["GetPersonPersonAddress"]
    email: Optional[str]
    given_name: Optional[str] = Field(alias="givenName")
    family_name: Optional[str] = Field(alias="familyName")
    phone_number: Optional[str] = Field(alias="phoneNumber")
    birth_date: Optional[Any] = Field(alias="birthDate")
    title: Optional[str]
    occupation: Optional[str]
    education: Optional[str]
    works_for: Optional[List[Optional["GetPersonPersonWorksFor"]]] = Field(
        alias="worksFor"
    )
    affiliation: Optional[List[Optional["GetPersonPersonAffiliation"]]]
    member_of: Optional[List[Optional["GetPersonPersonMemberOf"]]] = Field(
        alias="memberOf"
    )
    alumni_of: Optional[List[Optional["GetPersonPersonAlumniOf"]]] = Field(
        alias="alumniOf"
    )
    birth_place: Optional["GetPersonPersonBirthPlace"] = Field(alias="birthPlace")
    death_place: Optional["GetPersonPersonDeathPlace"] = Field(alias="deathPlace")
    home_location: Optional[List[Optional["GetPersonPersonHomeLocation"]]] = Field(
        alias="homeLocation"
    )
    work_location: Optional[List[Optional["GetPersonPersonWorkLocation"]]] = Field(
        alias="workLocation"
    )


class GetPersonPersonOwner(BaseModel):
    id: str


class GetPersonPersonFeeds(BaseModel):
    id: str
    name: str


class GetPersonPersonLinks(BaseModel):
    uri: Optional[Any]
    link_type: Optional[LinkTypes] = Field(alias="linkType")
    excerpts: Optional[str]


class GetPersonPersonWorkflow(BaseModel):
    id: str
    name: str


class GetPersonPersonLocation(BaseModel):
    latitude: Optional[float]
    longitude: Optional[float]


class GetPersonPersonH3(BaseModel):
    h_3_r_0: Optional[str] = Field(alias="h3r0")
    h_3_r_1: Optional[str] = Field(alias="h3r1")
    h_3_r_2: Optional[str] = Field(alias="h3r2")
    h_3_r_3: Optional[str] = Field(alias="h3r3")
    h_3_r_4: Optional[str] = Field(alias="h3r4")
    h_3_r_5: Optional[str] = Field(alias="h3r5")
    h_3_r_6: Optional[str] = Field(alias="h3r6")
    h_3_r_7: Optional[str] = Field(alias="h3r7")
    h_3_r_8: Optional[str] = Field(alias="h3r8")
    h_3_r_9: Optional[str] = Field(alias="h3r9")
    h_3_r_10: Optional[str] = Field(alias="h3r10")
    h_3_r_11: Optional[str] = Field(alias="h3r11")
    h_3_r_12: Optional[str] = Field(alias="h3r12")
    h_3_r_13: Optional[str] = Field(alias="h3r13")
    h_3_r_14: Optional[str] = Field(alias="h3r14")
    h_3_r_15: Optional[str] = Field(alias="h3r15")


class GetPersonPersonAddress(BaseModel):
    street_address: Optional[str] = Field(alias="streetAddress")
    city: Optional[str]
    region: Optional[str]
    country: Optional[str]
    postal_code: Optional[str] = Field(alias="postalCode")


class GetPersonPersonWorksFor(BaseModel):
    id: str
    name: str


class GetPersonPersonAffiliation(BaseModel):
    id: str
    name: str


class GetPersonPersonMemberOf(BaseModel):
    id: str
    name: str


class GetPersonPersonAlumniOf(BaseModel):
    id: str
    name: str


class GetPersonPersonBirthPlace(BaseModel):
    id: str
    name: str


class GetPersonPersonDeathPlace(BaseModel):
    id: str
    name: str


class GetPersonPersonHomeLocation(BaseModel):
    id: str
    name: str


class GetPersonPersonWorkLocation(BaseModel):
    id: str
    name: str


GetPerson.model_rebuild()
GetPersonPerson.model_rebuild()
