# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class ExtractContents(BaseModel):
    extract_contents: Optional[List[Optional["ExtractContentsExtractContents"]]] = (
        Field(alias="extractContents")
    )


class ExtractContentsExtractContents(BaseModel):
    specification: Optional["ExtractContentsExtractContentsSpecification"]
    content: Optional["ExtractContentsExtractContentsContent"]
    name: str
    value: str
    start_time: Optional[Any] = Field(alias="startTime")
    end_time: Optional[Any] = Field(alias="endTime")
    page_number: Optional[int] = Field(alias="pageNumber")
    error: Optional[str]


class ExtractContentsExtractContentsSpecification(BaseModel):
    id: str


class ExtractContentsExtractContentsContent(BaseModel):
    id: str


ExtractContents.model_rebuild()
ExtractContentsExtractContents.model_rebuild()
