# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateMedicalProcedure(BaseModel):
    create_medical_procedure: Optional[
        "CreateMedicalProcedureCreateMedicalProcedure"
    ] = Field(alias="createMedicalProcedure")


class CreateMedicalProcedureCreateMedicalProcedure(BaseModel):
    id: str
    name: str


CreateMedicalProcedure.model_rebuild()
