# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteInvestmentFund(BaseModel):
    delete_investment_fund: Optional["DeleteInvestmentFundDeleteInvestmentFund"] = (
        Field(alias="deleteInvestmentFund")
    )


class DeleteInvestmentFundDeleteInvestmentFund(BaseModel):
    id: str
    state: EntityState


DeleteInvestmentFund.model_rebuild()
