# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class IsFeedDone(BaseModel):
    is_feed_done: Optional["IsFeedDoneIsFeedDone"] = Field(alias="isFeedDone")


class IsFeedDoneIsFeedDone(BaseModel):
    result: Optional[bool]


IsFeedDone.model_rebuild()
