# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateOrganization(BaseModel):
    create_organization: Optional["CreateOrganizationCreateOrganization"] = Field(
        alias="createOrganization"
    )


class CreateOrganizationCreateOrganization(BaseModel):
    id: str
    name: str


CreateOrganization.model_rebuild()
