# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class EnrichProducts(BaseModel):
    enrich_products: Optional[List[Optional["EnrichProductsEnrichProducts"]]] = Field(
        alias="enrichProducts"
    )


class EnrichProductsEnrichProducts(BaseModel):
    id: str
    name: str


EnrichProducts.model_rebuild()
