# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeletePlace(BaseModel):
    delete_place: Optional["DeletePlaceDeletePlace"] = Field(alias="deletePlace")


class DeletePlaceDeletePlace(BaseModel):
    id: str
    state: EntityState


DeletePlace.model_rebuild()
