# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateInvestmentFund(BaseModel):
    update_investment_fund: Optional["UpdateInvestmentFundUpdateInvestmentFund"] = (
        Field(alias="updateInvestmentFund")
    )


class UpdateInvestmentFundUpdateInvestmentFund(BaseModel):
    id: str
    name: str


UpdateInvestmentFund.model_rebuild()
