# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountInvestmentFunds(BaseModel):
    count_investment_funds: Optional["CountInvestmentFundsCountInvestmentFunds"] = (
        Field(alias="countInvestmentFunds")
    )


class CountInvestmentFundsCountInvestmentFunds(BaseModel):
    count: Optional[Any]


CountInvestmentFunds.model_rebuild()
