# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateInvestment(BaseModel):
    update_investment: Optional["UpdateInvestmentUpdateInvestment"] = Field(
        alias="updateInvestment"
    )


class UpdateInvestmentUpdateInvestment(BaseModel):
    id: str
    name: str


UpdateInvestment.model_rebuild()
