# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllInvestmentFunds(BaseModel):
    delete_all_investment_funds: Optional[
        List[Optional["DeleteAllInvestmentFundsDeleteAllInvestmentFunds"]]
    ] = Field(alias="deleteAllInvestmentFunds")


class DeleteAllInvestmentFundsDeleteAllInvestmentFunds(BaseModel):
    id: str
    state: EntityState


DeleteAllInvestmentFunds.model_rebuild()
