# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateInvestment(BaseModel):
    create_investment: Optional["CreateInvestmentCreateInvestment"] = Field(
        alias="createInvestment"
    )


class CreateInvestmentCreateInvestment(BaseModel):
    id: str
    name: str


CreateInvestment.model_rebuild()
