# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountWorkflows(BaseModel):
    count_workflows: Optional["CountWorkflowsCountWorkflows"] = Field(
        alias="countWorkflows"
    )


class CountWorkflowsCountWorkflows(BaseModel):
    count: Optional[Any]


CountWorkflows.model_rebuild()
