# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class EnableUser(BaseModel):
    enable_user: Optional["EnableUserEnableUser"] = Field(alias="enableUser")


class EnableUserEnableUser(BaseModel):
    id: str
    state: EntityState


EnableUser.model_rebuild()
