# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteProduct(BaseModel):
    delete_product: Optional["DeleteProductDeleteProduct"] = Field(
        alias="deleteProduct"
    )


class DeleteProductDeleteProduct(BaseModel):
    id: str
    state: EntityState


DeleteProduct.model_rebuild()
