# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ConnectorTypes, EntityState


class UpdateConnector(BaseModel):
    update_connector: Optional["UpdateConnectorUpdateConnector"] = Field(
        alias="updateConnector"
    )


class UpdateConnectorUpdateConnector(BaseModel):
    id: str
    name: str
    state: EntityState
    type: Optional[ConnectorTypes]


UpdateConnector.model_rebuild()
