# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateMedicalDrug(BaseModel):
    create_medical_drug: Optional["CreateMedicalDrugCreateMedicalDrug"] = Field(
        alias="createMedicalDrug"
    )


class CreateMedicalDrugCreateMedicalDrug(BaseModel):
    id: str
    name: str


CreateMedicalDrug.model_rebuild()
