# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class ResearchContents(BaseModel):
    research_contents: Optional["ResearchContentsResearchContents"] = Field(
        alias="researchContents"
    )


class ResearchContentsResearchContents(BaseModel):
    result: Optional[str]


ResearchContents.model_rebuild()
