# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteInvestments(BaseModel):
    delete_investments: Optional[
        List[Optional["DeleteInvestmentsDeleteInvestments"]]
    ] = Field(alias="deleteInvestments")


class DeleteInvestmentsDeleteInvestments(BaseModel):
    id: str
    state: EntityState


DeleteInvestments.model_rebuild()
