# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState, LinkTypes


class QueryOrganizationsExpanded(BaseModel):
    organizations: Optional["QueryOrganizationsExpandedOrganizations"]


class QueryOrganizationsExpandedOrganizations(BaseModel):
    results: Optional[List[Optional["QueryOrganizationsExpandedOrganizationsResults"]]]


class QueryOrganizationsExpandedOrganizationsResults(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    relevance: Optional[float]
    owner: "QueryOrganizationsExpandedOrganizationsResultsOwner"
    state: EntityState
    alternate_names: Optional[List[Optional[str]]] = Field(alias="alternateNames")
    uri: Optional[Any]
    description: Optional[str]
    identifier: Optional[str]
    thing: Optional[str]
    feeds: Optional[
        List[Optional["QueryOrganizationsExpandedOrganizationsResultsFeeds"]]
    ]
    links: Optional[
        List[Optional["QueryOrganizationsExpandedOrganizationsResultsLinks"]]
    ]
    workflow: Optional["QueryOrganizationsExpandedOrganizationsResultsWorkflow"]
    location: Optional["QueryOrganizationsExpandedOrganizationsResultsLocation"]
    h_3: Optional["QueryOrganizationsExpandedOrganizationsResultsH3"] = Field(
        alias="h3"
    )
    address: Optional["QueryOrganizationsExpandedOrganizationsResultsAddress"]
    founding_date: Optional[Any] = Field(alias="foundingDate")
    email: Optional[str]
    telephone: Optional[str]
    legal_name: Optional[str] = Field(alias="legalName")
    industries: Optional[List[Optional[str]]]
    revenue: Optional[Any]
    revenue_currency: Optional[str] = Field(alias="revenueCurrency")
    investment: Optional[Any]
    investment_currency: Optional[str] = Field(alias="investmentCurrency")
    founders: Optional[
        List[Optional["QueryOrganizationsExpandedOrganizationsResultsFounders"]]
    ]
    employees: Optional[
        List[Optional["QueryOrganizationsExpandedOrganizationsResultsEmployees"]]
    ]
    members: Optional[
        List[Optional["QueryOrganizationsExpandedOrganizationsResultsMembers"]]
    ]
    parent_organization: Optional[
        "QueryOrganizationsExpandedOrganizationsResultsParentOrganization"
    ] = Field(alias="parentOrganization")
    member_of: Optional[
        List[Optional["QueryOrganizationsExpandedOrganizationsResultsMemberOf"]]
    ] = Field(alias="memberOf")
    sub_organizations: Optional[
        List[Optional["QueryOrganizationsExpandedOrganizationsResultsSubOrganizations"]]
    ] = Field(alias="subOrganizations")
    locations: Optional[
        List[Optional["QueryOrganizationsExpandedOrganizationsResultsLocations"]]
    ]
    investments_received: Optional[
        List[
            Optional[
                "QueryOrganizationsExpandedOrganizationsResultsInvestmentsReceived"
            ]
        ]
    ] = Field(alias="investmentsReceived")
    investor_funds: Optional[
        List[Optional["QueryOrganizationsExpandedOrganizationsResultsInvestorFunds"]]
    ] = Field(alias="investorFunds")


class QueryOrganizationsExpandedOrganizationsResultsOwner(BaseModel):
    id: str


class QueryOrganizationsExpandedOrganizationsResultsFeeds(BaseModel):
    id: str
    name: str


class QueryOrganizationsExpandedOrganizationsResultsLinks(BaseModel):
    uri: Optional[Any]
    link_type: Optional[LinkTypes] = Field(alias="linkType")
    excerpts: Optional[str]


class QueryOrganizationsExpandedOrganizationsResultsWorkflow(BaseModel):
    id: str
    name: str


class QueryOrganizationsExpandedOrganizationsResultsLocation(BaseModel):
    latitude: Optional[float]
    longitude: Optional[float]


class QueryOrganizationsExpandedOrganizationsResultsH3(BaseModel):
    h_3_r_0: Optional[str] = Field(alias="h3r0")
    h_3_r_1: Optional[str] = Field(alias="h3r1")
    h_3_r_2: Optional[str] = Field(alias="h3r2")
    h_3_r_3: Optional[str] = Field(alias="h3r3")
    h_3_r_4: Optional[str] = Field(alias="h3r4")
    h_3_r_5: Optional[str] = Field(alias="h3r5")
    h_3_r_6: Optional[str] = Field(alias="h3r6")
    h_3_r_7: Optional[str] = Field(alias="h3r7")
    h_3_r_8: Optional[str] = Field(alias="h3r8")
    h_3_r_9: Optional[str] = Field(alias="h3r9")
    h_3_r_10: Optional[str] = Field(alias="h3r10")
    h_3_r_11: Optional[str] = Field(alias="h3r11")
    h_3_r_12: Optional[str] = Field(alias="h3r12")
    h_3_r_13: Optional[str] = Field(alias="h3r13")
    h_3_r_14: Optional[str] = Field(alias="h3r14")
    h_3_r_15: Optional[str] = Field(alias="h3r15")


class QueryOrganizationsExpandedOrganizationsResultsAddress(BaseModel):
    street_address: Optional[str] = Field(alias="streetAddress")
    city: Optional[str]
    region: Optional[str]
    country: Optional[str]
    postal_code: Optional[str] = Field(alias="postalCode")


class QueryOrganizationsExpandedOrganizationsResultsFounders(BaseModel):
    id: str
    name: str


class QueryOrganizationsExpandedOrganizationsResultsEmployees(BaseModel):
    id: str
    name: str


class QueryOrganizationsExpandedOrganizationsResultsMembers(BaseModel):
    id: str
    name: str


class QueryOrganizationsExpandedOrganizationsResultsParentOrganization(BaseModel):
    id: str
    name: str


class QueryOrganizationsExpandedOrganizationsResultsMemberOf(BaseModel):
    id: str
    name: str


class QueryOrganizationsExpandedOrganizationsResultsSubOrganizations(BaseModel):
    id: str
    name: str


class QueryOrganizationsExpandedOrganizationsResultsLocations(BaseModel):
    id: str
    name: str


class QueryOrganizationsExpandedOrganizationsResultsInvestmentsReceived(BaseModel):
    id: str
    name: str


class QueryOrganizationsExpandedOrganizationsResultsInvestorFunds(BaseModel):
    id: str
    name: str


QueryOrganizationsExpanded.model_rebuild()
QueryOrganizationsExpandedOrganizations.model_rebuild()
QueryOrganizationsExpandedOrganizationsResults.model_rebuild()
