# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetCategory(BaseModel):
    category: Optional["GetCategoryCategory"]


class GetCategoryCategory(BaseModel):
    id: str
    name: str
    description: Optional[str]
    creation_date: Any = Field(alias="creationDate")
    feeds: Optional[List[Optional["GetCategoryCategoryFeeds"]]]


class GetCategoryCategoryFeeds(BaseModel):
    id: str
    name: str


GetCategory.model_rebuild()
GetCategoryCategory.model_rebuild()
