# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import SummarizationTypes


class SummarizeContents(BaseModel):
    summarize_contents: Optional[
        List[Optional["SummarizeContentsSummarizeContents"]]
    ] = Field(alias="summarizeContents")


class SummarizeContentsSummarizeContents(BaseModel):
    specification: Optional["SummarizeContentsSummarizeContentsSpecification"]
    content: Optional["SummarizeContentsSummarizeContentsContent"]
    type: SummarizationTypes
    items: Optional[List["SummarizeContentsSummarizeContentsItems"]]
    error: Optional[str]


class SummarizeContentsSummarizeContentsSpecification(BaseModel):
    id: str


class SummarizeContentsSummarizeContentsContent(BaseModel):
    id: str


class SummarizeContentsSummarizeContentsItems(BaseModel):
    text: Optional[str]
    tokens: int
    summarization_time: Optional[Any] = Field(alias="summarizationTime")


SummarizeContents.model_rebuild()
SummarizeContentsSummarizeContents.model_rebuild()
