# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteConversations(BaseModel):
    delete_conversations: Optional[
        List[Optional["DeleteConversationsDeleteConversations"]]
    ] = Field(alias="deleteConversations")


class DeleteConversationsDeleteConversations(BaseModel):
    id: str
    state: EntityState


DeleteConversations.model_rebuild()
